// Copyright 2025 Zentrum für Digitale Souveränität der Öffentlichen Verwaltung (ZenDiS) GmbH.
// SPDX-License-Identifier: MIT

import { Loader2 } from 'lucide-react'
import React, { FunctionComponent } from 'react'
import { useForm } from 'react-hook-form'
import { useToast } from '../hooks/use-toast'
import { apiCall, SarifApiResponse } from '../lib/apiClient'
import { Button } from './ui/button'
import { Form, FormItem } from './ui/form'
import { Input } from './ui/input'
import { Label } from './ui/label'

interface Props {
    onScanFinished: (response: SarifApiResponse) => void
    displayLabel?: boolean
    pleaseWait: string
    test: string
}

const CheckRepoForm: FunctionComponent<Props> = ({
    onScanFinished,
    displayLabel,
    pleaseWait,
    test,
}) => {
    const form = useForm<{
        repositoryUrl: string
    }>()
    const [isPending, setIsPending] = React.useState(false)
    const { toast } = useToast()

    const handleSubmit = async ({
        repositoryUrl,
    }: {
        repositoryUrl: string
    }) => {
        if (isPending) {
            return
        }
        setIsPending(true)

        try {
            const url = new URL(repositoryUrl)

            // valid url.
            // lets url encode it
            const encodedUri = encodeURIComponent(url.toString())

            const resp = await apiCall('/repositories/' + encodedUri + '/sarif')
            const json: SarifApiResponse = await resp.json()
            onScanFinished(json)
            form.reset()
        } catch (e) {
            console.error(e)
            toast({
                title: 'Die angegebene Url ist ungültig',
                description:
                    'Bitte überprüfen Sie, ob die von Ihnen angegebene URL einen Tippfehler enthält. Stellen Sie sicher, dass Sie die gesamte URL des Repos angeben, ohne die Endung .git.',
            })
        } finally {
            setIsPending(false)
        }
    }

    return (
        <Form {...form}>
            <form onSubmit={form.handleSubmit(handleSubmit)}>
                <FormItem>
                    {displayLabel && (
                        <Label className="relative font-space-grotesk text-xl text-white">
                            Repository URL
                        </Label>
                    )}
                    <div className="flex flex-row gap-4">
                        <Input
                            type="url"
                            className="border-transparent"
                            placeholder="https://gitlab.opencode.de/open-code/badgebackend/badge-api"
                            {...form.register('repositoryUrl')}
                        />
                        {isPending ? (
                            <Button className="border-transparent" disabled>
                                <Loader2 className="animate-spin" />
                                {pleaseWait}
                            </Button>
                        ) : (
                            <Button
                                className="border-transparent"
                                type="submit"
                                variant={'default'}
                            >
                                {test}
                            </Button>
                        )}
                    </div>
                </FormItem>
            </form>
        </Form>
    )
}

export default CheckRepoForm
